summaryrefslogtreecommitdiff
path: root/audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp
diff options
context:
space:
mode:
authorGirish Pattabiraman <[email protected]>2018-08-13 10:54:19 -0700
committerAdonais Romero González <[email protected]>2018-08-13 10:54:19 -0700
commit2af3e666d01a60568c2875b4ccbd56b122ad714f (patch)
tree29825a7b7cb0f6a9f77f1ab6e5813665d45ca4cc /audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp
parent181c180357cdf9a04d5e3bb21a8e86dc2155ca69 (diff)
Update sample to get ready for RS4 changes - merge pre-RS4 fixes. (#256)
* Format Changes ============== * Add KSEVENT_PINCAPS_FORMATCHANGE to Bluetooth HFP Endpoints * Remove 8 bit formats from Bluetooth HFP Endpoints Name Template ============== * Bluetooth Endpoints are now based on templates in INF and then customized with endpoints specific data Sideband Common Interface for future Sideband buses =================================================== * Add ISidebandDevice * Add current directory to TabletAudioSample include path. Remove unused compiler flags. * RS4 bug fixes
Diffstat (limited to 'audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp')
-rw-r--r--audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp19
1 files changed, 15 insertions, 4 deletions
diff --git a/audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp b/audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp
index 77f12e41..db705a68 100644
--- a/audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp
+++ b/audio/sysvad/EndpointsCommon/bthhfpminwavert.cpp
@@ -92,18 +92,18 @@ Return Value:
}
else if (PropertyRequest->Verb & KSPROPERTY_TYPE_GET)
{
- ASSERT(m_BthHfpDevice != NULL);
+ ASSERT(m_pSidebandDevice != NULL);
//
// bHfpNrecPresent is set to TRUE when the HF (remote device) handles NR + EC.
// Note that GetNRECDisableStatus() returns TRUE if the HF notified the AG to disable
// the NR + EC locally.
//
- BOOL bHfpNrecPresent = m_BthHfpDevice->IsNRECSupported() && m_BthHfpDevice->GetNRECDisableStatus();
+ BOOL bSidebandNrecPresent = m_pSidebandDevice->IsNRECSupported() && m_pSidebandDevice->GetNRECDisableStatus();
// If it is HFP render pin (data flow in) or if the NR-EC is not supported,
// return size 0 effect list
- if (IsSystemRenderPin(nPinId) || !bHfpNrecPresent)
+ if (IsSystemRenderPin(nPinId) || !bSidebandNrecPresent)
{
PropertyRequest->ValueSize = 0;
ntStatus = STATUS_SUCCESS;
@@ -182,6 +182,13 @@ Return Value:
case KSPROPERTY_PIN_PROPOSEDATAFORMAT:
ntStatus = waveRt->PropertyHandlerProposedFormat(PropertyRequest);
break;
+
+ case KSPROPERTY_PIN_PROPOSEDATAFORMAT2:
+ ntStatus = waveRt->PropertyHandlerProposedFormat2(PropertyRequest);
+ break;
+
+ default:
+ DPF(D_TERSE, ("[PropertyHandler_BthHfpWaveFilter: Invalid Device Request]"));
}
}
else if (IsEqualGUIDAligned(*PropertyRequest->PropertyItem->Set, KSPROPSETID_AudioEffectsDiscovery))
@@ -191,6 +198,9 @@ Return Value:
case KSPROPERTY_AUDIOEFFECTSDISCOVERY_EFFECTSLIST:
ntStatus = waveRt->PropertyHandler_BthHfpAudioEffectsDiscoveryEffectsList(PropertyRequest);
break;
+
+ default:
+ DPF(D_TERSE, ("[PropertyHandler_BthHfpWaveFilter: Invalid Device Request]"));
}
}
@@ -204,3 +214,4 @@ Return Value:
+
@@ -92,18 +92,18 @@ Return Value:
//
- // bHfpNrecPresent is set to TRUE when the HF (remote device) handles NR + EC.
+ // bSidebandNrecPresent is set to TRUE when the HF (remote device) handles NR + EC.
// Note that GetNRECDisableStatus() returns TRUE if the HF notified the AG to disable
// the NR + EC locally.